Class: Mandrill::Tags

Inherits:
Object
  • Object
show all
Defined in:
lib/mandrill/api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(master) ⇒ Tags



609
610
611
# File 'lib/mandrill/api.rb', line 609

def initialize(master)
    @master = master
end

Instance Attribute Details

#masterObject

Returns the value of attribute master.



607
608
609
# File 'lib/mandrill/api.rb', line 607

def master
  @master
end

Instance Method Details

#all_time_seriesArray

Return the recent history (hourly stats for the last 30 days) for all tags



760
761
762
763
# File 'lib/mandrill/api.rb', line 760

def all_time_series()
    _params = {}
    return @master.call 'tags/all-time-series', _params
end

#delete(tag) ⇒ Hash

Deletes a tag permanently. Deleting a tag removes the tag from any messages that have been sent, and also deletes the tag’s stats. There is no way to undo this operation, so use it carefully.



648
649
650
651
# File 'lib/mandrill/api.rb', line 648

def delete(tag)
    _params = {:tag => tag}
    return @master.call 'tags/delete', _params
end

#info(tag) ⇒ Hash

Return more detailed information about a single tag, including aggregates of recent stats



721
722
723
724
# File 'lib/mandrill/api.rb', line 721

def info(tag)
    _params = {:tag => tag}
    return @master.call 'tags/info', _params
end

#listArray

Return all of the user-defined tag information



628
629
630
631
# File 'lib/mandrill/api.rb', line 628

def list()
    _params = {}
    return @master.call 'tags/list', _params
end

#time_series(tag) ⇒ Array

Return the recent history (hourly stats for the last 30 days) for a tag



741
742
743
744
# File 'lib/mandrill/api.rb', line 741

def time_series(tag)
    _params = {:tag => tag}
    return @master.call 'tags/time-series', _params
end