Class: Mandrill::Whitelists

Inherits:
Object
  • Object
show all
Defined in:
lib/mandrill/api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(master) ⇒ Whitelists



791
792
793
# File 'lib/mandrill/api.rb', line 791

def initialize(master)
    @master = master
end

Instance Attribute Details

#masterObject

Returns the value of attribute master.



789
790
791
# File 'lib/mandrill/api.rb', line 789

def master
  @master
end

Instance Method Details

#add(email) ⇒ Hash

Adds an email to your email rejection whitelist. If the address is currently on your blacklist, that blacklist entry will be removed automatically.



800
801
802
803
# File 'lib/mandrill/api.rb', line 800

def add(email)
    _params = {:email => email}
    return @master.call 'whitelists/add', _params
end

#delete(email) ⇒ Hash

Removes an email address from the whitelist.



822
823
824
825
# File 'lib/mandrill/api.rb', line 822

def delete(email)
    _params = {:email => email}
    return @master.call 'whitelists/delete', _params
end

#list(email = nil) ⇒ Array

Retrieves your email rejection whitelist. You can provide an email address or search prefix to limit the results. Returns up to 1000 results.



812
813
814
815
# File 'lib/mandrill/api.rb', line 812

def list(email=nil)
    _params = {:email => email}
    return @master.call 'whitelists/list', _params
end